<?php
/**
 * Divine_Spa Theme Customizer.
 *
 * @package Divine_Spa
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function divine_spa_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';   

	// Remove the core header textcolor control, as it shares the site titel & text color.
	$wp_customize->remove_control( 'header_textcolor' );
 
	// Add main text color setting and control.
	$wp_customize->add_setting(
		'site_title_text_color',
		array(
			'default'           => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
			'transport'         => 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'site_title_text_color',
			array(
				'label'   => __( 'Site Title & Text Color', 'divine-spa' ),
				'section' => 'colors',
			)
		)
	);

	$wp_customize->add_section( 'v_copyright' , array(
	    'title'      => __( 'Footer Settings', 'divine-spa' ),
	    'priority'   => 90,
	) );
	$wp_customize->add_setting( 'v_copyright_text' , array(
	    'default'     => '',
	    'transport'   => 'postMessage', 
	    'sanitize_callback' => 'sanitize_text_field',
	) ); 
	$wp_customize->add_control( 'v_copyright_text', array(
	    'label' => __( 'Copyright Text', 'divine-spa' ),
		'section'	=> 'v_copyright',
		'setting'	=> 'v_copyright_text',
		'type'	 => 'text',
        'description'   => __( 'Write copyright text here.', 'divine-spa' )
	) ); 
}
add_action( 'customize_register', 'divine_spa_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function divine_spa_customize_preview_js() {
	wp_enqueue_script( 'divine_spa_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'divine_spa_customize_preview_js' );
